"use strict";
this.name = "ams_system";
this.author = "Thargoid, modded by Wyvern";
this.copyright = "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description = "Modded to launch decoys intstead of darts, for a much more reliable system.";
this.version = "2.04";

this.startUp = function () {
	if (missionVariables.amCount === undefined || missionVariables.amCount === null) {
		this.amCount = 25;
	} else {
		this.amCount = missionVariables.amCount;
	}
	if (missionVariables.amActive === undefined || missionVariables.amActive === null) {
		missionVariables.amActive = "INACTIVE";
	}
}

this.guiScreenWillChange = function(to, from)
	{
	if(to === "GUI_SCREEN_MANIFEST")
		{
		switch(player.ship.equipmentStatus("EQ_AMS"))
			{
			case "EQUIPMENT_OK":
				{
				if(missionVariables.amCount > 0)
					{ this.amsDisplay = "AMS decoy packs - " + missionVariables.amCount;}
				else
					{ this.amsDisplay = "AMS offline - launcher empty"; }			
				mission.setInstructions(this.amsDisplay); 
				break;
				}
		
			case "EQUIPMENT_DAMAGED":
				{
				mission.setInstructions("AMS offline - damaged");
				break;
				}			
			
			case "EQUIPMENT_UNAVAILABLE":
			case "EQUIPMENT_UNKNOWN":
				{
				mission.setInstructions(null);
				break;
				}
			}
		}	
	}

this.shipLaunchedFromStation = function () {
	if (player.ship.equipmentStatus("EQ_AMS") === "EQUIPMENT_OK") {
		missionVariables.amActive = "ACTIVE";
		switch (this.amCount) {
			case 0:
				{
					player.consoleMessage("AMS - System offline, no decoy packs loaded.", 5);
					break;
				}
			case 1:
				{
					player.consoleMessage("AMS - System online, 1 decoy pack loaded.", 5);
					break;
				}
			default:
				{
					player.consoleMessage("AMS - System online, " + this.amCount + " decoy packs loaded.", 5);
					break;
				}
		}
	}

}

this.$scanForMissiles = function () {
	function missileArray(entity) {
		return entity.isShip && entity.isMissile && entity.target && entity.target === player.ship;
	};
	let incomingMissiles = system.filteredEntities(this, missileArray, player.ship, 25600);
	if (incomingMissiles.length > 0) {
		this.shipAttackedWithMissile(incomingMissiles[0], null);
	}
}

this.shipAttackedWithMissile = function (missile, whom) {
	if (player.ship.equipmentStatus("EQ_AMS") === "EQUIPMENT_OK" && missionVariables.amActive === "ACTIVE" && this.amCount > 0) {
		player.consoleMessage("AMS - Decoys " + (7 - this.amCount) + " launched.", 6);
		let antiMissile = player.ship.spawnOne("ams_decoy_package");
		antiMissile.target = missile;
		let amOrientation = player.ship.orientation;
		let offsetVector = amOrientation.vectorUp(); // vector at right angles to the player, downwards
		let spawnOffset = offsetVector.multiply(20); // set the offset to 20m downwards (for larger ships, increase 20).
		antiMissile.orientation = amOrientation; // point the dart in the same direction as the player
		antiMissile.position = player.ship.position.subtract(spawnOffset); // move the dart to it's correct start point.

		if (--this.amCount < 1) {
			player.consoleMessage("AMS - system exhausted, shutting down", 8);
		}
		missionVariables.amCount = this.amCount;
	}
}

this.playerBoughtEquipment = function (equipment) {
	switch (equipment) {
		case "EQ_AMS":
			{
				missionVariables.amActive = "ACTIVE";
				this.amCount = 25;
				break;
			}
			case "EQ_AMS_RELOAD":
			{
				this.amCount = 25;
				player.ship.removeEquipment("EQ_AMS_RELOAD");
				break;
			}
		case "EQ_AMS_REMOVAL":
			{
				player.ship.removeEquipment("EQ_AMS");
				player.ship.removeEquipment("EQ_AMS_REMOVAL");
				player.credits += (5000 + (this.amCount * 30));
				this.amCount = 0;
				delete missionVariables.amCount;
				delete missionVariables.amActive;
				break;
			}
	}
	missionVariables.amCount = this.amCount;
}